@@ -60,7 +60,8 @@ def parse_axi_values_file(filename="/var/lib/apt-xapian-index/values"):
     if not os.path.exists(filename):
         return axi_values
     for raw_line in open(filename):
-        line = string.split(raw_line, "#", 1)[0]
+        #line = string.split(raw_line, "#", 1)[0]
+        line = str.split(raw_line, "#", 1)[0]
         if line.strip() == "":
             continue
         (key, value) = line.split()
@@ -167,7 +168,7 @@ class StoreDatabase(GObject.GObject):
                 xapiandb.add_database(axi)
             except Exception as e:
                 logging.warn("failed to add apt-xapian-index db %s" % e)
-                print "Failed to add apt-xapian-index,some software may not be searched"
+                print("Failed to add apt-xapian-index,some software may not be searched")
         if (self._use_agent and
                 os.path.exists(XAPIAN_BASE_PATH_SOFTWARE_CENTER_AGENT)):
             try:
@@ -409,7 +410,7 @@ class Search:
         try:
             self.db.xapiandb
         except:
-            print "Failed to add db"
+            print("Failed to add db")
             #LOG.exception("failed to add db")
         self.db.open()
         
@@ -418,7 +419,7 @@ class Search:
         #------Filter out single word in search keyword (include chinese)------
         self.db.reopen()
         try:
-            tem_keyword = unicode(keyword, "utf-8")
+            tem_keyword = str(keyword, "utf-8")
         except:
             keyword = keyword
         else:
@@ -441,10 +442,13 @@ class Search:
 #            print '************************************'
             pkgname = doc.get_value(XapianValues.PKGNAME)
 
+
             if not pkgname:
                 pkgname = doc.get_data()
 
             if pkgname:
+                if (isinstance(pkgname,bytes)):
+                    pkgname = pkgname.decode(encoding='utf-8')
                 #check the pkgname exist in the list or not
                 try:
                     index = pkgnamelist.index(pkgname)
