@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -31,10 +31,10 @@ import time
 import logging
 import threading
 import multiprocessing
-import Queue
+import queue
 from piston_mini_client import auth
 
-from PyQt4.QtCore import *
+from PyQt5.QtCore import *
 
 from models.globals import Globals
 from models.category import Category
@@ -49,10 +49,11 @@ from models.globals import Globals
 from models.enums import (UBUNTUKYLIN_SERVER, UBUNTUKYLIN_RES_PATH, UBUNTUKYLIN_DATA_CAT_PATH, UBUNTUKYLIN_RES_SCREENSHOT_PATH)
 from models.enums import Signals,UnicodeToAscii
 
-from backend.remote.piston_remoter import PistonRemoterAuth
+#from backend.remote.piston_remoter import PistonRemoterAuth
 
 import aptsources.sourceslist
-from urllib2 import urlopen, URLError, HTTPError
+from urllib.request import urlopen
+from urllib.error import URLError, HTTPError
 from ftplib import FTP
 
 LOG = logging.getLogger("uksc")
@@ -66,18 +67,18 @@ class ThreadWorker(threading.Thread):
     def __init__(self,appmgr):
         threading.Thread.__init__(self)
         self.appmgr = appmgr
-	#self = appmgr
+        #self = appmgr
         self.apt_cache = None
-	self.db = Database()
-	#self.appmgr.db = self.db 
-	self.cat_list = {}
+        self.db = Database()
+        #self.appmgr.db = self.db 
+        self.cat_list = {}
     def run(self):
-	fl = 1
+        fl = 1
         while True:
-	    if(fl == 1):
-	        fl = 0
-		#self.appmgr.db = self.db
-	        self._init_models()
+            if(fl == 1):
+                fl = 0
+                #self.appmgr.db = self.db
+                self._init_models()
 
     def open_cache(self):
         locale.setlocale(locale.LC_ALL, "zh_CN.UTF-8")
@@ -85,40 +86,43 @@ class ThreadWorker(threading.Thread):
             self.apt_cache = apt.Cache()
         self.apt_cache.open()
         self.pkgcount = len(self.apt_cache)
-	#if (self.pkgcount < 2000):
-	#	self.appmgr.for_update = 1
+        #if (self.pkgcount < 2000):
+        #        self.appmgr.for_update = 1
 
     def _init_models(self):
         self.open_cache()
         self.cat_list = self.get_category_list_from_db()
-	self.appmgr.cat_list = self.cat_list
-	self.appmgr.apt_cache = self.apt_cache
-	self.appmgr.db = self.db
-#	self.appmgr.get_recommend_apps(False)
-#	self.appmgr.get_ratingrank_apps(False)
-	sum_inst = 0
+        self.appmgr.cat_list = self.cat_list
+        self.appmgr.apt_cache = self.apt_cache
+        self.appmgr.db = self.db
+        if Globals.UPDATE_HOM == 0:
+            #self.appmgr.get_recommend_apps(False)
+            self.appmgr.get_ratingrank_apps(False)
+        sum_inst = 0
         sum_up = 0
         sum_all = len(self.apt_cache)
-	self.appmgr.get_recommend_apps(False)
-	self.appmgr.get_ratingrank_apps(False)
-	print "ok",sum_all
-	#QApplication.slot_recommend_apps_ready(applist, bysignal)	
-	exit()
+        #self.appmgr.get_recommend_apps(False)
+        self.appmgr.get_ratingrank_apps(False)
+        print(("ok",sum_all))
+        self.appmgr.get_game_apps(False,False)
+        self.appmgr.get_necessary_apps(False,False)
+
+        #QApplication.slot_recommend_apps_ready(applist, bysignal)        
+        exit()
 
     def get_category_list_from_db(self):
-        list = self.db.query_categories()
+        lists = self.db.query_categories()
         cat_list = {}
-        for item in list:
-            c = UnicodeToAscii(item[2])
-            # c = item[2]
+        for item in lists:
+            c = item[2]
             zhcnc = item[3]
             index = item[4] 
             visible = (item[0]==1)
 
-            icon = UBUNTUKYLIN_RES_PATH + c + ".png"
+            icon = UBUNTUKYLIN_RES_PATH + str(c) + ".png"
             cat = Category(c, zhcnc, index, visible, icon, self.get_category_apps_from_db(c))
             cat_list[c] = cat
-	    self.appmgr.cat_list = cat_list
+            self.appmgr.cat_list = cat_list
 
         Globals.ALL_APPS = {}
         return cat_list
@@ -132,12 +136,13 @@ class ThreadWorker(threading.Thread):
         return cat_list
 
     def get_category_apps_from_db(self,cat,catdir=""):
-        list = self.db.query_category_apps(cat)
+        lists = self.db.query_category_apps(cat)
         apps = {}
-        for item in list:
-            pkgname = UnicodeToAscii(item[0])
+        for item in lists:
+            #pkgname = UnicodeToAscii(item[0])
+            pkgname = item[0]
             displayname_cn = item[1]
-            if pkgname in Globals.ALL_APPS.keys():
+            if pkgname in list(Globals.ALL_APPS.keys()):
                 apps[pkgname] = Globals.ALL_APPS[pkgname]
             else:
                 app = Application(pkgname,displayname_cn, cat, self.apt_cache)
@@ -196,7 +201,7 @@ class ThreadWorkerDaemon(threading.Thread):
             item = self.appmgr.worklist.pop()
             self.appmgr.mutex.release()
 
-            print 'work thread get item : ',item.funcname
+            print(('work thread get item : ',item.funcname))
 
             if item is None:
                 continue
@@ -206,30 +211,30 @@ class ThreadWorkerDaemon(threading.Thread):
                 self.appmgr._update_models(item.kwargs)
             elif item.funcname == "init_models":
                 pass
-		#try:
+                #try:
                 #    self.appmgr._init_models()
                 #except Exception as e:
-                #    print "ThreadWorkerDaemon error", e.message
+                #    print "ThreadWorkerDaemon error", e
             elif item.funcname == "get_reviews":
                 try: #if no network the thread will be crashed, so add try except
                     reslist = self.appmgr.db.get_review_by_pkgname(item.kwargs['packagename'],item.kwargs['page'])
                 except Exception as e:
-                    print "ThreadWorkerDaemon error", e.message
+                    print(("ThreadWorkerDaemon error", e))
             elif item.funcname == "check_source_useable":
                 self.appmgr.start_check_source_useable()
             # elif item.funcname == "get_images":
             #     pass
             else:
-	##获取介绍
+        ##获取介绍
                 #event = multiprocessing.Event()
                 #queue = multiprocessing.Queue()
                 #spawn_helper = SpawnProcess(item.funcname,item.kwargs, event, queue)
                 #spawn_helper.daemon = True
                 #spawn_helper.start()
                 #event.wait()
-		#print "ccccccccccccccccccccccc", item.funcname,item.kwargs, event, queue
-		reslist = item.kwargs['thumbnailfile']
-		#print "vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv",reslist
+                #print "ccccccccccccccccccccccc", item.funcname,item.kwargs, event, queue
+                reslist = item.kwargs['thumbnailfile']
+                #print "vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv",reslist
                 #resLen = queue.qsize()
                 #while resLen:
                 #    try:
@@ -246,17 +251,17 @@ class ThreadWorkerDaemon(threading.Thread):
                 #    except Queue.Empty:
                 #        #print "&&&&&&&&&&get error33333333333333:",queue.qsize()
                 #        count += 1
-		
+                
                 #    resLen = queue.qsize()
                 #print "receive data from backend process, func, qlen, len=",item.funcname,queue.qsize(),reslist
             #LOG.debug("receive data from backend process, len=%d",len(reslist))
             #self.appmgr.dispatchWorkerResult(item,reslist)
-	    LOG.debug("receive data from backend process, len=%d",len(reslist))
-	    self.appmgr.dispatchWorkerResult(item,reslist)
+            LOG.debug("receive data from backend process, len=%d",len(reslist))
+            self.appmgr.dispatchWorkerResult(item,reslist)
 
 
 #This class is the abstraction of application management
-class AppManager(QObject):
+class AppManager(QObject,Signals):
 
     # piston remoter
     premoter = ''
@@ -265,6 +270,8 @@ class AppManager(QObject):
     def __init__(self):
         #super(AppManager, self).__init__()
         QObject.__init__(self)
+        self.premoter = PistonRemoter(service_root=UBUNTUKYLIN_SERVER)
+        self.login_in()
         self.name = "Ubuntu Kylin Software Center"
         self.apt_cache = None
         self.cat_list = {}
@@ -272,8 +279,8 @@ class AppManager(QObject):
         self.language = 'zh_CN'      #'any' for all
         self.distroseries = 'any'  #'any' for all
         self.db = Database()
-	#self.db = ""
-	self.for_update = 0
+        #self.db = ""
+        self.for_update = 0
         # silent process work queue
         self.squeue = multiprocessing.Queue()
         self.silent_process = SilentProcess(self.squeue)
@@ -285,23 +292,34 @@ class AppManager(QObject):
         self.worker_thread = ThreadWorkerDaemon(self)
         self.worker_thread.setDaemon(True)
         self.worker_thread.start()
-	
-	self.worker_thread1 = ThreadWorker(self)
+        
+        self.worker_thread1 = ThreadWorker(self)
         self.worker_thread1.setDaemon(True)
         self.worker_thread1.start()
 
 
-        self.premoter = PistonRemoter(service_root=UBUNTUKYLIN_SERVER)
+        #self.premoter = PistonRemoter(service_root=UBUNTUKYLIN_SERVER)
+
+    def login_in(self):
+        if Globals.AUTO_LOGIN == "1":
+            res = self.apprui_first_login(Globals.USER,Globals.PASSWORD)
+            #try:
+            #    res = self.apprui_first_login(Globals.USER,Globals.PASSWORD)
+            #except:
+            #    res = False
+            #print "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",res
+            if res != False and res != None and res not in list(range(1,4)) :
+                Globals.SHOW_LOGIN = 1
 
     # re new piston remoter auth by current login token
-    def reinit_premoter_auth(self):
-        authorizer = auth.OAuthAuthorizer(Globals.TOKEN["token"], Globals.TOKEN["token_secret"], Globals.TOKEN["consumer_key"], Globals.TOKEN["consumer_secret"])
-        self.premoterauth = PistonRemoterAuth(auth=authorizer)
+#    def reinit_premoter_auth(self):
+#        authorizer = auth.OAuthAuthorizer(Globals.TOKEN["token"], Globals.TOKEN["token_secret"], Globals.TOKEN["consumer_key"], Globals.TOKEN["consumer_secret"])
+#        self.premoterauth = PistonRemoterAuth(auth=authorizer)
 
     def check_source_update(self):
         f = QFile("/var/lib/apt/periodic/update-success-stamp")
-	if(self.for_update == 1):
-		return True
+        if(self.for_update == 1):
+                return True
         if(f.exists() == True):
             return False
         else:
@@ -322,7 +340,7 @@ class AppManager(QObject):
     #    self.cat_list = self.get_category_list_from_db()
 
     def init_models(self):
-	#print "self.appmgr.init_models()"
+        #print "self.appmgr.init_models()"
         item = WorkerItem("init_models",None)
         self.mutex.acquire()
         self.worklist.append(item)
@@ -330,13 +348,13 @@ class AppManager(QObject):
 
     def _update_models(self,kwargs):
         self.open_cache()
-        for cname,citem in self.cat_list.iteritems():
+        for cname,citem in list(self.cat_list.items()):
             apps = citem.apps
-            for aname,app in apps.iteritems():
+            for aname,app in list(apps.items()):
                 app.update_cache(self.apt_cache)
         if "update" == kwargs["action"]:
-            self.emit(Signals.count_application_update)
-        self.emit(Signals.refresh_page)
+            self.count_application_update.emit()
+        self.refresh_page.emit()
 
     def update_models(self,action, pkgname=""):
         kwargs = {"packagename": pkgname,
@@ -353,13 +371,13 @@ class AppManager(QObject):
         list = self.db.query_categories()
         cat_list = {}
         for item in list:
-            c = UnicodeToAscii(item[2])
-            # c = item[2]
+            #c = UnicodeToAscii(item[2])
+            c = item[2]
             zhcnc = item[3]
             index = item[4]
             visible = (item[0]==1)
 
-            icon = UBUNTUKYLIN_RES_PATH + c + ".png"
+            icon = UBUNTUKYLIN_RES_PATH + str(c) + ".png"
             cat = Category(c, zhcnc, index, visible, icon, self.get_category_apps_from_db(c))
             cat_list[c] = cat
 
@@ -375,12 +393,13 @@ class AppManager(QObject):
         return cat_list
 
     def get_category_apps_from_db(self,cat,catdir=""):
-        list = self.db.query_category_apps(cat)
+        lists = self.db.query_category_apps(cat)
         apps = {}
-        for item in list:
-            pkgname = UnicodeToAscii(item[0])
+        for item in lists:
+            #pkgname = UnicodeToAscii(item[0])
+            pkgname = item[0]
             displayname_cn = item[1]
-            if pkgname in Globals.ALL_APPS.keys():
+            if pkgname in list(Globals.ALL_APPS.keys()):
                 apps[pkgname] = Globals.ALL_APPS[pkgname]
             else:
                 app = Application(pkgname,displayname_cn, cat, self.apt_cache)
@@ -440,11 +459,11 @@ class AppManager(QObject):
     def get_category_apps(self, cat, load=False, catdir=""):
         apps = {}
         if not cat:
-            for catName,catItem in self.cat_list.iteritems():
+            for catName,catItem in list(self.cat_list.items()):
                 if len(apps) == 0:
-                    apps = dict(catItem.apps.items())
+                    apps = dict(list(catItem.apps.items()))
                 else:
-                    apps = dict(apps.items() + catItem.apps.items())
+                    apps = dict(list(apps.items()) + list(catItem.apps.items()))
         else:
             #get the apps from category list
             if not load:
@@ -469,7 +488,7 @@ class AppManager(QObject):
         if self.cat_list is None:
             return None
         #
-        for (catname, cat) in self.cat_list.iteritems(): #get app in cat which init in uksc startup
+        for (catname, cat) in list(self.cat_list.items()): #get app in cat which init in uksc startup
             app = cat.get_application_byname(pkgname)
             if app is not None and app.package is not None:
                 return app
@@ -513,11 +532,11 @@ class AppManager(QObject):
         return package
 
     def get_application_count(self,cat_name=""):
-	self.apt_cache = self.worker_thread1.apt_cache
+        self.apt_cache = self.worker_thread1.apt_cache
         sum_inst = 0
         sum_up = 0
         #sum_all = len(self.apt_cache)
-	sum_all = len(self.apt_cache)
+        sum_all = len(self.apt_cache)
 
         if len(cat_name)>0:
             cat = self.cat_list[cat_name]
@@ -525,7 +544,8 @@ class AppManager(QObject):
         else:
             applist = self.db.query_applications()
             for item in applist:
-                pkgname = UnicodeToAscii(item[1])
+                #pkgname = UnicodeToAscii(item[1])
+                pkgname = item[1]
                 package = self.get_package_by_name(pkgname)
                 if package is None:
                     continue
@@ -555,20 +575,21 @@ class AppManager(QObject):
 
     #get advertisements, this is now implemented locally
     def get_advertisements(self, bysignal=False):
-        print "we need to get the advertisements"
+        print("we need to get the advertisements")
         tmpads = []
-        tmpads.append(Advertisement("pchomewallpaper", "url", "ad0.png", "adbground0.png", "http://download.pchome.net/wallpaper/"))
-        tmpads.append(Advertisement("qq", "url", "ad1.png", "adbground1.png", "http://www.ubuntukylin.com/ukylin/forum.php?mod=viewthread&tid=7688&extra=page%3D1"))
-        tmpads.append(Advertisement("wps", "pkg", "ad2.png", "adbground2.png", "wps-office"))
-        tmpads.append(Advertisement("dota2", "url", "ad3.png", "adbground3.png", "http://www.ubuntukylin.com/ukylin/forum.php?mod=viewthread&tid=7687&extra=page%3D1"))
-        tmpads.append(Advertisement("pps", "url", "ad4.png", "adbground4.png", "http://dl.pps.tv/pps_linux_download.html"))
-        tmpads.append(Advertisement("pchomewallpaper", "url", "ad5.png", "adbground5.png", "http://download.pchome.net/wallpaper/"))
-        self.emit(Signals.ads_ready, tmpads, bysignal)
+        tmpads.append(Advertisement("wps-office", "pkg", "ad2.png", "adb2.png", "wps-office"))
+        tmpads.append(Advertisement("netease-cloud-music", "pkg", "ad0.png", "adb0.png", "netease-cloud-music"))
+        tmpads.append(Advertisement("teamviewer", "pkg", "ad1.png", "adb1.png", "teamviewer"))
+        tmpads.append(Advertisement("wps-office", "pkg", "ad2.png", "adb2.png", "wps-office"))
+        tmpads.append(Advertisement("redeclipse", "pkg", "ad3.png", "adb3.png", "redeclipse"))
+        tmpads.append(Advertisement("eclipse", "pkg", "ad4.png", "adb4.png", "eclipse"))
+
+        self.ads_ready.emit(tmpads, bysignal)
 
     #get apps in ubuntukylin archives, this is now implemented with config file
     #then we can sync with the archive
     def get_ubuntukylin_apps(self):
-        print "we need to get the applications by condition recommend"
+        print("we need to get the applications by condition recommend")
         apps = self.get_category_apps("ubuntukylin")
         for(pkgname, app) in apps:
             if app is None or app.package is None:
@@ -578,7 +599,7 @@ class AppManager(QObject):
 
     #get rating and review status
     def get_rating_review_stats(self,callback=None):
-        print "we need to get the ratings and reviews stat"
+        print("we need to get the ratings and reviews stat")
         item  = WorkerItem("get_rating_review_stats",None)
         self.mutex.acquire()
         self.worklist.append(item)
@@ -602,7 +623,7 @@ class AppManager(QObject):
 
         # force == True means need get review from server immediately
         if reviews is not None and force == False:
-            print "get_application_reviews in memory"
+            print("get_application_reviews in memory")
             self.dispatchWorkerResult(item,reviews)
             return reviews
         else:
@@ -630,7 +651,7 @@ class AppManager(QObject):
 
         if app.screenshots:
             self.dispatchWorkerResult(item,app.screenshots)
-	    #print "vvvvvvvvvvvvvvvvvv",app.screenshots
+            #print "vvvvvvvvvvvvvvvvvv",app.screenshots
             return app.screenshots
 
         self.mutex.acquire()
@@ -640,7 +661,7 @@ class AppManager(QObject):
         return []
 
     def dispatchWorkerResult(self,item,reslist):
-	#print "item,===========,reslist",item,reslist
+        #print "item,===========,reslist",item,reslist
         if item.funcname == "get_reviews":
             # convert into our review objects
             LOG.debug("reviews ready:%s",len(reslist))
@@ -651,9 +672,9 @@ class AppManager(QObject):
             if app is not None and app.package is not None:
                 app.add_reviews(page,reviews)
             else:
-                print item.kwargs['packagename'], " not exist"
+                print((item.kwargs['packagename'], " not exist"))
 
-            self.emit(Signals.app_reviews_ready,reviews)
+            self.app_reviews_ready.emit(reviews)
         elif item.funcname == "get_screenshots":
             LOG.debug("screenshots ready:%s",len(reslist))
             screenshots = reslist
@@ -661,8 +682,8 @@ class AppManager(QObject):
             if app is not None and app.package is not None:
                 app.screenshots = screenshots
             else:
-                print item.kwargs['packagename'], " not exist"
-            self.emit(Signals.app_screenshots_ready,screenshots)
+                print((item.kwargs['packagename'], " not exist"))
+            self.app_screenshots_ready.emit(screenshots)
         elif item.funcname == "get_rating_review_stats":
             LOG.debug("rating review stats ready:%d",len(reslist))
             rnrStats = reslist
@@ -675,29 +696,29 @@ class AppManager(QObject):
                     app.ratings_average = rnrStat.ratings_average
                     app.ratings_total = rnrStat.ratings_total
                 if(str(rnrStat.pkgname) == "gparted"):
-                    print "######gparted ....", rnrStat.ratings_average,rnrStat.ratings_total, app
+                    print(("######gparted ....", rnrStat.ratings_average,rnrStat.ratings_total, app))
 
 
-            self.emit(Signals.rating_reviews_ready,rnrStats)
+            self.rating_reviews_ready.emit(rnrStats)
         elif item.funcname == "get_toprated_stats":
             LOG.debug("toprated stats ready:%d",len(reslist))
             topRated = reslist
 
-            self.emit(Signals.toprated_ready,topRated)
+            self.toprated_ready.emit(topRated)
         elif item.funcname == "update_models":
             LOG.debug("update apt cache ready")
             pkgname = item.kwargs["packagename"]
             action = item.kwargs["action"]
-            print "update apt cache ready:",len(reslist),pkgname
+            print(("update apt cache ready:",len(reslist),pkgname))
 
-            self.emit(Signals.apt_cache_update_ready, action, pkgname)
+            self.apt_cache_update_ready.emit(action, pkgname)
         elif item.funcname == "init_models":
             LOG.debug("init models ready")
-            self.emit(Signals.init_models_ready,"ok","获取分类信息完成")
-            print "init models后台运行中"
+            self.init_models_ready.emit("ok","获取分类信息完成")
+            print("init models后台运行中")
 
     def update_rating_reviews(self,rnrStats):
-        print "update_rating_reviews:",len(rnrStats)
+        print(("update_rating_reviews:",len(rnrStats)))
 
         for rnrStat in rnrStats:
             self.db.update_app_rnr(rnrStat.pkgname,rnrStat.ratings_average,rnrStat.ratings_total,rnrStat.reviews_total,0)
@@ -772,8 +793,34 @@ class AppManager(QObject):
             if(app is not None):
                 app.recommendrank = rec[1]
                 applist.append(app)
+        if Globals.UPDATE_HOM == 0:
+            self.recommend_ready.emit(applist, bysignal)
+
+     # get game apps
+    def get_game_apps(self, bysignal=False,sig = False):
+        recommends = self.db.get_game_apps()
+        applist = []
+        for rec in recommends:
+            app = self.get_application_by_name(rec[0])
+            if(app is not None):
+                app.recommendrank = rec[1]
+                applist.append(app)
+        if sig == True:
+            self.recommend_ready.emit(applist, bysignal)
+
+     # get necessary apps
+    def get_necessary_apps(self, bysignal=False,sig = False):
+        recommends = self.db.get_necessary_apps()
+        applist = []
+        for rec in recommends:
+            app = self.get_application_by_name(rec[0])
+            if(app is not None):
+                app.recommendrank = rec[1]
+                applist.append(app)
+        if sig == True:
+            self.recommend_ready.emit(applist, bysignal)
+
 
-        self.emit(Signals.recommend_ready, applist, bysignal)
 
     # get pointout apps
     def get_pointout_apps(self):
@@ -810,34 +857,37 @@ class AppManager(QObject):
                     applist.index(app)
                 except:
                     applist.append(app)
-
-        self.emit(Signals.ratingrank_ready, applist, bysignal)
+        if Globals.UPDATE_HOM == 0:
+            self.ratingrank_ready.emit(applist, bysignal)
 
     def submit_review(self, app_name, content):
         distroseries = get_distro_info()[2]
         language = get_language()
         try:
-            res = self.premoterauth.submit_review(app_name, content, distroseries, language, Globals.USER, Globals.USER_DISPLAY)
+            res = self.premoter.submit_review(app_name, content, distroseries, language, Globals.USER, Globals.USER_DISPLAY)
         except:
             res = "False"
-        self.emit(Signals.submit_review_over, res)
+        res = [{'res':res}]
+        self.submit_review_over.emit(res)
 
     def submit_translate_appinfo(self, appname,type_appname, type_summary, type_description, orig_appname, orig_summary, orig_description, trans_appname, trans_summary, trans_description):
         # distroseries = get_distro_info()[2]
         # language = get_language()
         try:
-            res = self.premoterauth.submit_translate_appinfo(appname,type_appname, type_summary, type_description, orig_appname, orig_summary, orig_description, trans_appname, trans_summary, trans_description, Globals.USER, Globals.USER_DISPLAY)
+            res = self.premoter.submit_translate_appinfo(appname,type_appname, type_summary, type_description, orig_appname, orig_summary, orig_description, trans_appname, trans_summary, trans_description, Globals.USER, Globals.USER_DISPLAY)
         except:
              res = "False"
-        self.emit(Signals.submit_translate_appinfo_over, res)
+        res = [{'res':res}]
+        self.submit_translate_appinfo_over.emit(res)
 
 
     def submit_rating(self, app_name, rating):
         try:
-            res = self.premoterauth.submit_rating(app_name, rating, Globals.USER, Globals.USER_DISPLAY)
+            res = self.premoter.submit_rating(app_name, rating, Globals.USER, Globals.USER_DISPLAY)
         except:
             res = False
-        self.emit(Signals.submit_rating_over, res)
+        res = [{'res':res}]
+        self.submit_rating_over.emit(res)
 
     # update app ratingavg in cache db after user do rating app
     def update_app_ratingavg(self, app_name, ratingavg, ratingtotal):
@@ -848,15 +898,113 @@ class AppManager(QObject):
             res = self.premoter.get_user_applist(Globals.USER)
         except:
             res = False
-        self.emit(Signals.get_user_applist_over, res)
+        res = [{'res':res}]
+        self.get_user_applist_over.emit(res)
 
     def get_user_transapplist(self):#zx 2015.01.30
         try:
             res = self.premoter.get_user_transapplist(Globals.USER)
         except:
             res = False
-        self.emit(Signals.get_user_transapplist_over, res)
+        res = [{'res':res}]
+        self.get_user_transapplist_over.emit(res)
 
+    def apprui_first_login(self,ui_username,ui_password):
+        #print "eeeeeeeeeeeeee",ui_username,ui_password
+        res = self.premoter.log_in_appinfo(ui_username,ui_password)
+        #print "ccccccccccccccccccccccccc",res
+        try:
+            if res == 1 or res == None:
+                #数据异常
+                print(("$$$$$$$$","自动登录数据异常"))
+            elif res == 2:
+                #用户验证失败
+                print(("$$$$$$$$","自动用户验证失败"))
+            elif res == 3:
+                #服务器异常
+                print(("$$$$$$$$","自动服务器异常"))
+            else :
+                print(("$$$$$$$$","自动登录成功"))
+                data = res[0]
+                rem = res[1]
+                rem = rem[0]
+                res = data[0]
+                Globals.USER = res["username"]
+                Globals.USER_DISPLAY = res["username"]
+                Globals.EMAIL = res["email"]
+                #print "dddddddddddddd",Globals.USER,Globals.USER_DISPLAY
+                Globals.USER_DISPLAY = Globals.USER = res["username"]
+                Globals.USER_IDEN = rem["identity"]
+                Globals.LAST_LOGIN = res["last_login"]
+                Globals.USER_LEVEL = rem["level"]
+                Globals.PASSWORD = self.listlogin[1]
+                print(("$$$$$$$$",Globals.USER_IDEN,Globals.USER_LEVEL))
+
+        except:
+            print(("$$$$$$$$","自动服务器异常"))
+
+
+    def ui_first_login(self,ui_username,ui_password):
+        #print "eeeeeeeeeeeeee",ui_username,ui_password
+        res = self.premoter.log_in_appinfo(ui_username,ui_password)
+        #print "res============",res
+        res = [{'res':res}]
+        self.get_ui_first_login_over.emit(res)
+
+    def ui_login(self,ui_username,ui_password):
+        #print "eeeeeeeeeeeeee",ui_username,ui_password
+        try:
+            res = self.premoter.log_in_appinfo(ui_username,ui_password)
+        except:
+            res = False
+        #print "res============",res
+        res = [{'res':res}]
+        self.get_ui_login_over.emit(res)
+
+    def ui_adduser(self,ui_username,ui_password,ui_email,ui_iden):
+        #print "ffffffffffffffff",ui_username,ui_password,ui_email,ui_iden
+        try:
+            res = self.premoter.submit_add_user(ui_username,ui_password,ui_email,ui_iden)
+        except:
+            res = False
+        #print "res============",res
+        res = [{'res':res}]
+        self.get_ui_adduser_over.emit(res)
+
+    def rset_password(self,new_password):
+        try:
+            res = self.premoter.rset_user_password(Globals.USER,new_password)
+        except:
+            res = False
+        res = [{'res':res}]
+        self.rset_password_over.emit(res)
+
+    def recover_password(self,old_username,old_email,new_password):
+        try:
+            res = self.premoter.rset_user_password(old_username,old_email)
+        except:
+            res = False
+        if res == 0:
+            try:
+                rer = self.premoter.rset_user_password(old_username,new_password)
+            except:
+                rer = False
+        else:
+            rer = res
+        res = [{'res':rer}]
+        self.recover_password_over.emit(res)        
+
+    def change_identity(self):
+        if Globals.USER_IDEN == "general_user":
+            us_iden = "developer"
+        elif Globals.USER_IDEN == "developer":
+            us_iden = "general_user"
+        try:
+            res = self.premoter.change_user_identity(Globals.USER,us_iden)
+        except:
+            res = False
+        res = [{'res':res}]
+        self.change_user_identity_over.emit(res)
 
     #--------------------------------add by kobe for windows replace----------------------------------
     def search_name_and_categories_record(self):
@@ -906,21 +1054,21 @@ class AppManager(QObject):
                 pass
             else:
                 source_url = "http://" + source_url[num+1:]
-            print source_url
+            print(source_url)
             #source_url = source_str[0]
             try:
-                response = urllib2.urlopen(source_url, timeout=30)
+                response = urllib.request.urlopen(source_url, timeout=30)
                 #print response.info()
-            except HTTPError, e:
-                print e.code
+            except HTTPError as e:
+                print((e.code))
                 if e.code != 401:
                     bad_source_urllist.append(source_url)
-            except Exception, e:
-                print e
+            except Exception as e:
+                print(e)
                 bad_source_urllist.append(source_url)
         if bad_source_urllist != []:
-            print 'bad source urllist:',bad_source_urllist
-            self.emit(Signals.check_source_useable_over,bad_source_urllist)
+            print(('bad source urllist:',bad_source_urllist))
+            self.check_source_useable_over.emit(bad_source_urllist)
         #print "check source useable over"
 
     def sourcelist_need_update(self):
@@ -936,15 +1084,15 @@ class AppManager(QObject):
 
 def _reviews_ready_callback(str_pkgname, reviews_data, my_votes=None,
                         action=None, single_review=None):
-    print "\n***Enter _reviews_ready_callback..."
-    print str_pkgname
+    print("\n***Enter _reviews_ready_callback...")
+    print(str_pkgname)
     for review in reviews_data:
-      print "rating: %s  user=%s" % (review.rating,
-          review.reviewer_username)
-      print review.summary
-      print review.review_text
-      print "\n"
-    print "\n\n"
+      print(("rating: %s  user=%s" % (review.rating,
+          review.reviewer_username)))
+      print((review.summary))
+      print((review.review_text))
+      print("\n")
+    print("\n\n")
 
 
 if __name__ == "__main__":
@@ -952,7 +1100,7 @@ if __name__ == "__main__":
     #初始化打开cache
     appManager = AppManager()
     appManager.open_cache()
-    print appManager.name
+    print((appManager.name))
     #加载软件分类
     cat_list = appManager.get_category_list(True,"../data/category/")
 #    print appManager.cat_list
@@ -960,11 +1108,11 @@ if __name__ == "__main__":
  #   print appManager.get_category_apps('')
     app = appManager.get_application_by_name("abe")
     ver = app.package.candidate
-    print ver.record
-    print ver.uri
+    print((ver.record))
+    print((ver.uri))
 #    print app
 #    apps = appManager.get_recommend_apps()
-    print app
+    print(app)
 #    print app.thumbnail
 #    print app.screenshot
 #    appManager.get_application_screenshots("gimp","/home/maclin/test/")
@@ -973,7 +1121,7 @@ if __name__ == "__main__":
 #    appManager.get_application_reviews("gimp",_reviews_ready_callback)
 #    appManager.get_rating_review_stats()
 #    appManager.get_toprated_stats()
-    print "waiting..........\n\n"
+    print("waiting..........\n\n")
     while True:
-        print "***"
+        print("***")
         time.sleep(2)
