@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -25,6 +25,7 @@
 import xapian
 import sqlite3
 import os
+import re
 from models.review import Review
 from models.enums import UBUNTUKYLIN_SERVER,UBUNTUKYLIN_DATA_PATH,UKSC_CACHE_DIR,UnicodeToAscii
 from backend.remote.piston_remoter import PistonRemoter
@@ -46,6 +47,9 @@ QUERY_NAME_CATEGORIES = "select id,app_name,categories,windows_app_name from xp
 QUERY_APP_ACCORD_CATEGORIES = "select app_name,display_name,windows_app_name,display_name_windows,description from xp where categories='%s'"
 UPDATE_EXISTS = "update xp set exists_valid='%d' where id='%d'"
 
+import threading
+lock = threading.Lock()
+
 class Database:
 
     def __init__(self):
@@ -56,7 +60,7 @@ class Database:
         # no cache file, copy
         if not os.path.exists(destFile):
             if not os.path.exists(srcFile):
-                print "error with db file"
+                print("error with db file")
                 return
             open(destFile, "wb").write(open(srcFile, "rb").read())
 
@@ -79,16 +83,16 @@ class Database:
         # no cache file, copy
         if not os.path.exists(xapian_destFile):
             if not os.path.exists(xapian_srcFile):
-                print "No xapiandb source in /usr/share/ubuntu-kylin-software-center/data/,please reinstall it"
+                print("No xapiandb source in /usr/share/ubuntu-kylin-software-center/data/,please reinstall it")
                 return
             copytree(xapian_srcFile,xapian_destFile)
-            print "Xapiandb has been copy to cache"
+            print("Xapiandb has been copy to cache")
 
         # cache xapiandb need update, copy
         if self.is_xapiancachedb_need_update():
             rmtree(xapian_destFile)
             copytree(xapian_srcFile,xapian_destFile)
-            print "cache xapiandb versin updated"
+            print("cache xapiandb versin updated")
 
 
     def query_categories(self):
@@ -101,6 +105,7 @@ class Database:
         al = ''
 
         sql = "select id from category where name='%s'"
+
         self.cursor.execute(sql % cate_name)
         res = self.cursor.fetchall()
         cateid = ''
@@ -115,6 +120,11 @@ class Database:
             cstring = i[1]
             cs = cstring.split(',')
             for c in cs:
+                #将unicode中的非数字的部分去掉,数据库被不正确修改后的错误
+                if c.isdigit():
+                    #c = list(filter(str.isdigit, c.encode("utf-8")))
+                    c = re.sub("\D","",c)
+                    c = c.encode("utf-8")
                 if(int(cateid) == int(c)):
                     al += str(aid)
                     al += ','
@@ -151,9 +161,13 @@ class Database:
             return res
 
     def update_app_rnr(self,pkgname,rating_average,rating_total,review_total,download_total=0):
-        print "update_app_rnr:",self.updatecount,pkgname,rating_average,rating_total,review_total,download_total
-        self.cursor.execute(UPDATE_APP_RNR % (rating_average,rating_total,review_total,download_total,pkgname))
-        self.connect.commit()
+        print(("update_app_rnr:",self.updatecount,pkgname,rating_average,rating_total,review_total,download_total))
+        try:
+            lock.acquire(True)
+            self.cursor.execute(UPDATE_APP_RNR % (rating_average,rating_total,review_total,download_total,pkgname))
+            self.connect.commit()
+        finally:
+            lock.release()
         #res = self.cursor.fetchall()
         #print "update_app_rnr:",len(res),res
         self.updatecount += 1
@@ -221,7 +235,7 @@ class Database:
                     for old_item in old_matches:
                         old_doc = old_item.document
                         old_version = old_doc.get_value(1) #valueslot:1 xapiandb version
-            print "old xapiandb  version:",old_version," new xapiandb version:",new_version
+            print(("old xapiandb  version:",old_version," new xapiandb version:",new_version))
         except:
             return True
         else:
@@ -267,12 +281,20 @@ class Database:
                         date = str(review.date)
                         date = date.replace('T',' ')
                         date = date.replace('Z','')
-
-                        self.cursor.execute("insert into review values(?,?,'',?,?,?,'zh_CN','',0,0)", (id,aid,content,user_display,date))
+                        try:
+                            lock.acquire(True)
+                            self.cursor.execute("insert into review values(?,?,'',?,?,?,'zh_CN','',0,0)", (id,aid,content,user_display,date))
+                            self.connect.commit()
+                        finally:
+                            lock.release()
 
                     if(review_total != ''):
-                        self.cursor.execute("update application set review_total=? where id=?", (review_total,aid))
-                    self.connect.commit()
+                        try:
+                            lock.acquire(True)
+                            self.cursor.execute("update application set review_total=? where id=?", (review_total,aid))
+                            self.connect.commit()
+                        finally:
+                            lock.release()
 
             # normal init, check and download newest reviews
             else:
@@ -306,7 +328,13 @@ class Database:
 
                             # download
                             if(rid != id):
-                                self.cursor.execute("insert or ignore into review values(?,?,'',?,?,?,'zh_CN','',0,0)", (rid,aid,content,user_display,date))
+                                try:
+                                    lock.acquire(True)
+                                    self.cursor.execute("insert or ignore into review values(?,?,'',?,?,?,'zh_CN','',0,0)", (rid,aid,content,user_display,date))
+                                    self.connect.commit()
+                                finally:
+                                    lock.release()
+
                             # end download
                             else:
                                 # stop 'while'
@@ -322,7 +350,12 @@ class Database:
                                 break
 
                         if(review_total != ''):
-                            self.cursor.execute("update application set review_total=? where id=?", (review_total,aid))
+                            try:
+                                lock.acquire(True)
+                                self.cursor.execute("update application set review_total=? where id=?", (review_total,aid))
+                                self.connect.commit()
+                            finally:
+                                lock.release()
 
                         startpage += 1
 
@@ -347,11 +380,20 @@ class Database:
                         date = date.replace('Z','')
 
                         # ignore the same review by id
-                        self.cursor.execute("insert or ignore into review values(?,?,'',?,?,?,'zh_CN','',0,0)", (id,aid,content,user_display,date))
+                        try:
+                            lock.acquire(True)
+                            self.cursor.execute("insert or ignore into review values(?,?,'',?,?,?,'zh_CN','',0,0)", (id,aid,content,user_display,date))
+                            self.connect.commit()
+                        finally:
+                            lock.release()
 
                     if(review_total != ''):
-                        self.cursor.execute("update application set review_total=? where id=?", (review_total,aid))
-                    self.connect.commit()
+                        try:
+                            lock.acquire(True)
+                            self.cursor.execute("update application set review_total=? where id=?", (review_total,aid))
+                            self.connect.commit()
+                        finally:
+                            lock.release()
 
 
         # all download check over, return reviews to show
@@ -386,8 +428,12 @@ class Database:
             value = 'True'
         else:
             value = 'False'
-        self.cursor.execute("update dict set value=? where key='pointout'", (value,))
-        self.connect.commit()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("update dict set value=? where key='pointout'", (value,))
+            self.connect.commit()
+        finally:
+            lock.release()
 
     def get_pointout_apps(self):
         self.cursor.execute("select app_name,rank_pointout from rank,application where rank_pointout!=0 and rank.aid_id=application.id order by rank_pointout")
@@ -400,28 +446,138 @@ class Database:
         return pointouts
 
     def get_recommend_apps(self):
-        self.cursor.execute("select app_name,rank_recommend from rank,application where rank_recommend!=0 and rank.aid_id=application.id order by rank_recommend")
-        res = self.cursor.fetchall()
+        #self.cursor.execute("select app_name,rank_recommend from rank,application where rank_recommend!=0 and rank.aid_id=application.id order by rank_recommend")
+        #self.cursor.execute("select app_name,rank from application where application.rank!=0 order by rank")
+        #res = self.cursor.fetchall()
         recommends = []
-        for item in res:
-            app_name = item[0]
-            rank_recommend = item[1]
-            recommends.append((app_name, rank_recommend))
+        #for item in res:
+        #    app_name = item[0]
+        #    print "ddddddddddddddddd",app_name,item[1]
+        #    rank_recommend = item[1]
+        #    recommends.append((app_name, rank_recommend))
+        recommends.append(("youker-assistant","1"))
+        recommends.append(("atom","3"))
+        recommends.append(("google-chrome-stable","3"))
+        recommends.append(("sogoupinyin","1"))
+        recommends.append(("skypeforlinux","6"))
+        recommends.append(("lovewallpaper","3"))
+        recommends.append(("franz","3"))
+        recommends.append(("youdao-dict","3"))
+        recommends.append(("foxitreader","8"))
+        recommends.append(("ppsspp","3"))
+        recommends.append(("virtualbox","6"))
+        recommends.append(("thunderbird","7"))
+        recommends.append(("openshot","12"))
+        recommends.append(("firefox","11"))
+        recommends.append(("wireshark","9"))
+        recommends.append(("librecad","12"))
+        recommends.append(("flashplugin-installer","13"))
+        recommends.append(("brasero","13"))
+        recommends.append(("uget","5"))
+        recommends.append(("calibre","10"))
+        recommends.append(("gimp","3"))
+        recommends.append(("gtk-recordmydesktop","3"))
+        recommends.append(("transgui","3"))
+        recommends.append(("pluma","3"))
+        recommends.append(("gnome-calculator","3"))
+#recommends.append(("virtualbox","4"))
+# youker-assistant gimp sogoupinyin virtualbox wine playonlinux freecad
+        return recommends
+    def get_game_apps(self):
+        #self.cursor.execute("select app_name,rank_recommend from rank,application where rank_recommend!=0 and rank.aid_id=application.id order by rank_recommend")
+        #self.cursor.execute("select app_name,rank from application where application.rank!=0 order by rank")
+        #res = self.cursor.fetchall()
+        recommends = []
+        #for item in res:
+        #    app_name = item[0]
+        #    print "ddddddddddddddddd",app_name,item[1]
+        #    rank_recommend = item[1]
+        #    recommends.append((app_name, rank_recommend))
+        recommends.append(("playonlinux","2"))
+        recommends.append(("steam-launcher","3"))
+        recommends.append(("ppsspp","3"))
+        recommends.append(("crossover","3"))
+        recommends.append(("wine1.6","1"))
+        recommends.append(("supertuxkart","4"))
+        recommends.append(("kodi","1"))
+        recommends.append(("aisleriot","1"))
+        recommends.append(("gnome-chess","7"))
+        recommends.append(("supertux","7"))
+        recommends.append(("gnchess","11"))
+        recommends.append(("flightgear","10"))
+        recommends.append(("kmahjongg","6"))
+        recommends.append(("frozen-bubble","9"))
+        recommends.append(("gnome-hearts","8"))
+        recommends.append(("gnome-mines","13"))
+        recommends.append(("smplayer","14"))
+        recommends.append(("openrocket","5"))
+        recommends.append(("gnome-mahjongg","12"))
+        recommends.append(("funnyboat","12"))
+        recommends.append(("kylin-video","12"))
+# youker-assistant gimp sogoupinyin virtualbox wine playonlinux freecad
+        return recommends
+
+    def get_necessary_apps(self):
+        recommends = []
+        recommends.append(("opera","2"))
+        recommends.append(("filezilla","2"))
+        recommends.append(("remmina","3"))
+        recommends.append(("obs-studio","3"))
+        recommends.append(("freecad","4"))
+        recommends.append(("unetbootin","5"))
+        recommends.append(("codeblocks","6"))
+        recommends.append(("chromium-browser","8"))
+        recommends.append(("transmission","7"))
+        recommends.append(("deluge","8"))
+        recommends.append(("hardinfo","9"))
+        recommends.append(("nautilus","10"))
+        recommends.append(("bluefish","11"))
+        recommends.append(("gnome-screenshot","12"))
+        recommends.append(("blender","13"))
+        recommends.append(("xmind","14"))
+        recommends.append(("vim","14"))
+        recommends.append(("midori","14"))
+        recommends.append(("notepadqq","8"))
+        recommends.append(("gnome-disk-utility","14"))
+        recommends.append(("shotcut","14"))
+        recommends.append(("gparted","14"))
         return recommends
 
     def get_ratingrank_apps(self):
-        self.cursor.execute("select app_name,rank_rating from rank,application where rank_rating!=0 and rank.aid_id=application.id order by rank_rating")
-        res = self.cursor.fetchall()
-        ratingranks = []
-        for item in res:
-            app_name = item[0]
-            rank_rating = item[1]
-            ratingranks.append((app_name, rank_rating))
-        return ratingranks
+        #self.cursor.execute("select app_name,rank_rating from rank,application where rank_rating!=0 and rank.aid_id=application.id order by rank_rating")
+        #res = self.cursor.fetchall()
+        #ratingranks = []
+        #for item in res:
+        #    app_name = item[0]
+        #    rank_rating = item[1]
+        #    ratingranks.append((app_name, rank_rating))
+        #return ratingranks
+        recommends = []
+        #recommends.append(("youker-assistant","1"))
+        recommends.append(("vlc","2"))
+        recommends.append(("synaptic","3"))
+        recommends.append(("gparted","3"))
+        recommends.append(("fcitx","3"))
+        recommends.append(("qtcreator","3"))
+        recommends.append(("rar","3"))
+        recommends.append(("shotwell","3"))
+        recommends.append(("stellarium","3"))
+        recommends.append(("ubuntu-restricted-extras","3"))
+        recommends.append(("stardict","3"))
+        recommends.append(("vim","14"))
+        recommends.append(("kylin-video","12"))
+        recommends.append(("gnome-screenshot","12"))
+        recommends.append(("empire","12"))
+        return recommends
+
 
     def update_app_ratingavg(self, app_name, ratingavg, ratingtotal):
-        self.cursor.execute("update application set rating_avg=?,rating_total=? where app_name=?", (ratingavg, ratingtotal, app_name))
-        self.connect.commit()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("update application set rating_avg=?,rating_total=? where app_name=?", (ratingavg, ratingtotal, app_name))
+            self.connect.commit()
+        finally:
+            lock.release()
 
     #------------add by kobe for windows replace------------
     def search_name_and_categories_record(self):
@@ -443,8 +599,12 @@ class Database:
 
     #------------add by kobe for windows replace------------
     def update_exists_data(self, exists, id):
-        self.cursor.execute(UPDATE_EXISTS % (exists, id))
-        self.connect.commit()
+        try:
+            lock.acquire(True)
+            self.cursor.execute(UPDATE_EXISTS % (exists, id))
+            self.connect.commit()
+        finally:
+            lock.release()
 
     def need_do_sourcelist_update(self):
         self.cursor.execute("select value from dict where key=?", ('sourcelist_need_update',))
@@ -454,14 +614,18 @@ class Database:
             return re
 
     def set_update_sourcelist_false(self):
-        self.cursor.execute("update dict set value=? where key='sourcelist_need_update'", ("False",))
-        self.connect.commit()
+        try:
+            lock.acquire(True)
+            self.cursor.execute("update dict set value=? where key='sourcelist_need_update'", ("False",))
+            self.connect.commit()
+        finally:
+            lock.release()
 
 if __name__ == "__main__":
     db = Database()
 
     # print db.get_pagecount_by_pkgname('gimp')
-    print db.is_cachedb_need_update()
+    print((db.is_cachedb_need_update()))
 
     # res = db.get_review_by_pkgname('gedit',2)
     # for item in res:
