@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -52,8 +52,18 @@ class Globals:
     # user name
     USER = ''
     USER_DISPLAY = ''
+    PASSWORD = ''
+    EMAIL = ''
+    LAST_LOGIN = ''
+    USER_IDEN = ''
+    USER_LEVEL = ''
+    SET_REM = ''
+    AUTO_LOGIN = ''
+    SHOW_LOGIN = 0
     TOKEN = ''
 
     NOWPAGE = -1
 
+    UPDATE_HOM = 0
+
     ALL_APPS = {}
