@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
 ### BEGIN LICENSE
@@ -24,8 +24,9 @@
 
 
 import os
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+from PyQt5.QtWidgets import *
+from PyQt5.QtGui import *
+from PyQt5.QtCore import *
 from ui.detailw import Ui_DetailWidget
 from ui.starwidget import StarWidget
 from ui.dynamicstarwidget import DynamicStarWidget
@@ -40,12 +41,13 @@ from models.enums import (UBUNTUKYLIN_RES_ICON_PATH,
                         setLongTextToElideFormat,
                         PkgStates,
                         PageStates)
+from PyQt5 import QtGui
 from utils import run
 from utils import commontools
 from utils.debfile import DebFile
 from models.globals import Globals
 
-class DetailScrollWidget(QScrollArea):
+class DetailScrollWidget(QScrollArea,Signals):
     mainwindow = ''
     app = None
     debfile = ''
@@ -72,13 +74,13 @@ class DetailScrollWidget(QScrollArea):
         self.btns = MultiFunctionBtn(self.messageBox,self.detailWidget)
         self.btns.move(700, 24)
 
-        self.connect(self.btns,Signals.mfb_click_install,parent.slot_click_install)
-        self.connect(self.btns,Signals.mfb_click_uninstall,parent.slot_click_remove)
-        self.connect(self.btns,Signals.mfb_click_update,parent.slot_click_upgrade)
-        self.connect(self.btns, Signals.install_debfile, parent.slot_click_install_debfile)
+        self.btns.mfb_click_install.connect(parent.slot_click_install)
+        self.btns.mfb_click_uninstall.connect(parent.slot_click_remove)
+        self.btns.mfb_click_update.connect(parent.slot_click_upgrade)
+        self.btns.install_debfile.connect(parent.slot_click_install_debfile)
 
         # kobe 1106
-        self.connect(self.btns,Signals.get_card_status,parent.slot_get_normal_card_status)
+        self.btns.get_card_status.connect(parent.slot_get_normal_card_status)
 
         self.setWidget(self.detailWidget)
         self.bigsshot = ScreenShotBig()
@@ -104,7 +106,7 @@ class DetailScrollWidget(QScrollArea):
         self.smallstar.move(460, 45)
 
         self.star = StarWidget('big', 0, self.detailWidget)
-        self.star.move(90, 584)
+        self.star.move(90, 540)
 
         self.hl = QLineEdit(self.detailWidget)
         self.hl.setGeometry(-10,-10,1,1)
@@ -120,6 +122,19 @@ class DetailScrollWidget(QScrollArea):
         self.ui.btnSshotNext.setFocusPolicy(Qt.NoFocus)
         self.ui.reviewListWidget.setFocusPolicy(Qt.NoFocus)
         self.ui.thumbnail.setFocusPolicy(Qt.NoFocus)
+        self.ui.thumbnail_2.setFocusPolicy(Qt.NoFocus)
+        self.ui.thumbnail_3.setFocusPolicy(Qt.NoFocus)
+        self.ui.pushButton.setFocusPolicy(Qt.NoFocus)
+        self.ui.pushButton_2.setFocusPolicy(Qt.NoFocus)
+        self.ui.pushButton_3.setFocusPolicy(Qt.NoFocus)
+        self.ui.pushButton_4.setFocusPolicy(Qt.NoFocus)
+        self.ui.pushButton_5.setFocusPolicy(Qt.NoFocus)
+        self.ui.pushButton.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_2.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_3.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_4.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_5.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+
         self.ui.sshot.setFocusPolicy(Qt.NoFocus)
         #self.ui.name.setFocusPolicy(Qt.StrongFocus)
 
@@ -132,7 +147,7 @@ class DetailScrollWidget(QScrollArea):
         # self.ui.btnInstall.clicked.connect(self.slot_click_install)
         # self.ui.btnUpdate.clicked.connect(self.slot_click_upgrade)
         # self.ui.btnUninstall.clicked.connect(self.slot_click_uninstall)
-        self.ui.thumbnail.clicked.connect(self.slot_show_sshot)
+        #self.ui.thumbnail.clicked.connect(self.slot_show_sshot)
         self.ui.sshot.clicked.connect(self.ui.sshot.hide)
         self.ui.bntSubmit.clicked.connect(self.slot_submit_review)
 
@@ -250,6 +265,16 @@ class DetailScrollWidget(QScrollArea):
         self.ui.reviewListWidget.setStyleSheet("QListWidget{background-color:transparent; border:0px;}QListWidget::item{height:85px;margin-top:-1px;border:0px;}")
 
         self.ui.thumbnail.hide()
+        self.ui.thumbnail_2.hide()
+        self.ui.thumbnail_3.hide()
+        self.ui.pushButton.hide()
+        self.ui.pushButton_2.hide()
+        self.ui.pushButton_3.hide()
+        self.ui.pushButton_4.hide()
+        self.ui.pushButton_5.hide()
+
+        self.ui.btnSshotBack.clicked.connect(self.slot_click_back)
+        self.ui.btnSshotNext.clicked.connect(self.slot_click_next)
 
         # mini loading div
         self.sshotload = MiniLoadingDiv(self.ui.sshotBG, self.detailWidget)
@@ -258,8 +283,167 @@ class DetailScrollWidget(QScrollArea):
         self.submitreviewload = MiniLoadingDiv(self.ui.reviewText, self.detailWidget)
         #self.submitchangedappinfoload = MiniLoadingDiv(self.ui.change_submit, self.detailWidget)
 
-        self.connect(self.mainwindow,Signals.apt_process_finish,self.slot_work_finished)
-        self.connect(self.mainwindow,Signals.apt_process_cancel,self.slot_work_cancel)
+        self.mainwindow.apt_process_finish.connect(self.slot_work_finished)
+        self.mainwindow.apt_process_cancel.connect(self.slot_work_cancel)
+
+#previous picture
+    def slot_click_back(self):
+        a = self.app.thumbnailfile
+
+
+        if self.now_shot == 1:
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(self.ntm))
+        else:
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(self.now_shot - 1))
+#        img = QPixmap(self.app.thumbnailfile)
+#        img = img.scaled(160,112)
+#        self.ui.thumbnail.resize(img.width(), img.height())
+#        self.ui.thumbnail.setStyleSheet("QPushButton{background-image:url('" + self.app.thumbnailfile + "');border:0px;}")
+#        self.ui.thumbnail.move(350, 324)
+#        self.ui.thumbnail.show()
+        image = QtGui.QImage()
+        image.load(self.app.thumbnailfile)
+        self.ui.thumbnail.setPixmap(QtGui.QPixmap.fromImage(image))
+        self.ui.thumbnail.resize(200,150)
+        self.ui.thumbnail.move(120, 315)
+        self.ui.thumbnail.show()
+
+        self.app.thumbnailfile = a
+        self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(self.now_shot))
+        #img = QPixmap(self.app.thumbnailfile)
+        #img = img.scaled(160,112)
+        #self.ui.thumbnail_3.resize(img.width(), img.height())
+        #self.ui.thumbnail_3.setStyleSheet("QPushButton{background-image:url('" + self.app.thumbnailfile + "');border:0px;}")
+        #self.ui.thumbnail_3.move(520, 324)
+        #self.ui.thumbnail_3.show()
+        image.load(self.app.thumbnailfile)
+        self.ui.thumbnail_2.setPixmap(QtGui.QPixmap.fromImage(image))
+        self.ui.thumbnail_2.resize(200,150)
+        self.ui.thumbnail_2.move(336, 315)
+        self.ui.thumbnail_2.show()
+
+
+        self.app.thumbnailfile = a
+        if self.now_shot == self.ntm:
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(1))
+        else:
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(self.now_shot + 1))
+        #img = QPixmap(self.app.thumbnailfile)
+        #img = img.scaled(160,112)
+        #self.ui.thumbnail_2.resize(img.width(), img.height())
+        #self.ui.thumbnail_2.setStyleSheet("QPushButton{background-image:url('" + self.app.thumbnailfile + "');border:0px;}")
+        #self.ui.thumbnail_2.move(180, 324)
+        #self.ui.thumbnail_2.show()
+        image.load(self.app.thumbnailfile)
+        self.ui.thumbnail_3.setPixmap(QtGui.QPixmap.fromImage(image))
+        self.ui.thumbnail_3.resize(200,150)
+        self.ui.thumbnail_3.move(552, 315)
+        self.app.thumbnailfile = a
+        if self.now_shot == 1:
+            self.now_shot = self.ntm
+        else:
+            self.now_shot = self.now_shot - 1
+        self.ui.pushButton.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_2.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_3.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_4.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_5.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        if self.now_shot == 1:
+            self.ui.pushButton.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+        elif self.now_shot == 2:
+            self.ui.pushButton_2.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+        elif self.now_shot == 3:
+            self.ui.pushButton_3.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+        elif self.now_shot == 4:
+            self.ui.pushButton_4.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+        elif self.now_shot == 5:
+            self.ui.pushButton_5.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+
+
+
+#next picture   
+    def slot_click_next(self):
+        a = self.app.thumbnailfile
+
+
+        if self.now_shot == self.ntm:
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(1))
+        else:
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(self.now_shot +1))
+        #img = QPixmap(self.app.thumbnailfile)
+        #img = img.scaled(160,112)
+        #self.ui.thumbnail.resize(img.width(), img.height())
+        #self.ui.thumbnail.setStyleSheet("QPushButton{background-image:url('" + self.app.thumbnailfile + "');border:0px;}")
+        #self.ui.thumbnail.move(350, 324)
+        #self.ui.thumbnail.show()
+        image = QtGui.QImage()
+        image.load(self.app.thumbnailfile)
+        self.ui.thumbnail.setPixmap(QtGui.QPixmap.fromImage(image))
+        self.ui.thumbnail.resize(200,150)
+        self.ui.thumbnail.move(120, 315)
+        self.ui.thumbnail.show()
+        self.app.thumbnailfile = a
+
+        if self.now_shot + 2 > self.ntm :
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(self.now_shot + 2 - self.ntm))
+        else:        
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(self.now_shot + 2))
+
+        #img = QPixmap(self.app.thumbnailfile)
+        #img = img.scaled(160,112)
+        #self.ui.thumbnail_2.resize(img.width(), img.height())
+        #self.ui.thumbnail_2.setStyleSheet("QPushButton{background-image:url('" + self.app.thumbnailfile + "');border:0px;}")
+        #self.ui.thumbnail_2.move(180, 324)
+        #self.ui.thumbnail_2.show()
+        #self.ui.thumbnail_2.hide()
+        image.load(self.app.thumbnailfile)
+        self.ui.thumbnail_2.setPixmap(QtGui.QPixmap.fromImage(image))
+        self.ui.thumbnail_2.resize(200,150)
+        self.ui.thumbnail_2.move(336, 315)
+        self.ui.thumbnail_2.show()
+
+
+        self.app.thumbnailfile = a
+        if self.now_shot + 3 > self.ntm :
+           self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(self.now_shot + 3 - self.ntm))
+        else:
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(self.now_shot + 3))
+#        img = QPixmap(self.app.thumbnailfile)
+#        img = img.scaled(160,112)
+#        self.ui.thumbnail_3.resize(img.width(), img.height())
+#        self.ui.thumbnail_3.setStyleSheet("QPushButton{background-image:url('" + self.app.thumbnailfile + "');border:0px;}")
+#        self.ui.thumbnail_3.move(520, 324)
+#        self.ui.thumbnail_3.show()
+        image.load(self.app.thumbnailfile)
+        self.ui.thumbnail_3.setPixmap(QtGui.QPixmap.fromImage(image))
+        self.ui.thumbnail_3.resize(200,150)
+        self.ui.thumbnail_3.move(552, 315)
+        self.ui.thumbnail_3.show()
+
+
+        self.app.thumbnailfile = a
+        if self.now_shot == self.ntm:
+            self.now_shot = 1
+        else:
+            self.now_shot = self.now_shot + 1
+
+        self.ui.pushButton.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_2.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_3.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_4.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_5.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        if self.now_shot == 1:
+            self.ui.pushButton.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+        elif self.now_shot == 2:
+            self.ui.pushButton_2.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+        elif self.now_shot == 3:
+            self.ui.pushButton_3.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+        elif self.now_shot == 4:
+            self.ui.pushButton_4.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+        elif self.now_shot == 5:
+            self.ui.pushButton_5.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
+
+
 
     def ui_init(self):
         self.ui = Ui_DetailWidget()
@@ -288,6 +472,8 @@ class DetailScrollWidget(QScrollArea):
         # clear sshot
         self.sshotcount = 0
         self.ui.thumbnail.hide()
+        self.ui.thumbnail_2.hide()
+        self.ui.thumbnail_3.hide()
 
         self.ui.change_submit.hide()#zx 2015.01.26
         self.ui.btn_change.hide()
@@ -345,7 +531,7 @@ class DetailScrollWidget(QScrollArea):
             self.debfile.is_installable = True
             self.btns.reset_btns(self.app, PkgStates.INSTALL, self.debfile)
         else:
-            print "it can not be installed......"
+            print("it can not be installed......")
             self.btns.reset_btns(self.app, PkgStates.INSTALL, self.debfile)
             self.messageBox.alert_msg("无法安装该软件包")
             # self.ui.btnInstall.setText("无法安装")
@@ -381,6 +567,9 @@ class DetailScrollWidget(QScrollArea):
         # clear sshot
         self.sshotcount = 0
         self.ui.thumbnail.hide()
+        self.ui.thumbnail_2.hide()
+        self.ui.thumbnail_3.hide()
+
 
         self.ui.candidateVersion.show()
         self.ui.fen.show()
@@ -460,8 +649,8 @@ class DetailScrollWidget(QScrollArea):
         self.star.show()
         #我的评分
         self.ratingstar = DynamicStarWidget(self.detailWidget)
-        self.ratingstar.move(630, 575)
-        self.connect(self.ratingstar, Signals.get_user_rating,self.slot_submit_rating)
+        self.ratingstar.move(630, 540)
+        self.ratingstar.get_user_rating.connect(self.slot_submit_rating)
 
         self.ui.transNameStatus.setStyleSheet("QLabel{background-image:url('res/installed.png')}")
         self.ui.transSummaryStatus.setStyleSheet("QLabel{background-image:url('res/installed.png')}")
@@ -601,12 +790,12 @@ class DetailScrollWidget(QScrollArea):
             else:
                 self.ui.description.setText(app.orig_description)
 
-            if str(self.ui.name.text().toUtf8()) == self.app.displayname and str(self.ui.summary.toPlainText()) == self.app.orig_summary and str(self.ui.description.toPlainText()) == self.app.orig_description:
+            if str(self.ui.name.text()) == self.app.displayname and str(self.ui.summary.toPlainText()) == self.app.orig_summary and str(self.ui.description.toPlainText()) == self.app.orig_description:
                 self.ui.btn_change.setText("翻译软件")
             else:
                 self.ui.btn_change.setText("完善翻译")
 
-        self.init_name = str(self.ui.name.text().toUtf8()).strip()
+        self.init_name = str(self.ui.name.text()).strip()
         self.init_summary = str(self.ui.summary.toPlainText()).strip()
         self.init_description = str(self.ui.description.toPlainText()).strip()
 
@@ -648,25 +837,111 @@ class DetailScrollWidget(QScrollArea):
         self.ui.reviewListWidget.setItemWidget(oneitem, rliw)
 
     def add_sshot(self, sclist):
+        self.ui.pushButton.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_2.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_3.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_4.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.ui.pushButton_5.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot2.png')}")
+        self.now_shot = 1
+        self.shlist = sclist
+        #print "xxxxxxxxxxxxxxxxx",sclist
         self.sshotcount = len(sclist)
+        if self.app.thumbnailfile.find('thumbnail1') != -1 :
+            #self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail1')
+            pass
+        elif self.app.thumbnailfile.find('thumbnail2') != -1 :
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail2','thumbnail1')
+        elif self.app.thumbnailfile.find('thumbnail3') != -1 :
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail3','thumbnail1')
+        else:
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail','thumbnail1')
+
+        self.shsave = self.app.thumbnailfile
+        self.shnum = self.app.thumbnailfile
+        for i in range (1,6) :
+            self.shnum = self.app.thumbnailfile.replace('thumbnail1','thumbnail' + str(i))
+            if os.path.exists(self.shnum):
+                #print "wwwwwwwwwwwwwwwwself.app.thumbnailfilew",self.shnum
+                pass
+            else:
+                i = i - 1
+                break
+        print("iiiiiiiiiiiiiiiiii",i)
+        self.ui.btnSshotBack.show()
+        self.ui.btnSshotNext.show()
+        self.ntm = i
+        if i <= 2 :
+            self.ui.btnSshotBack.hide()
+            self.ui.btnSshotNext.hide()
+            if i == 0 :
+                #self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail','thumbnail1')
+                pass
+        #else:
+         
+            #self.ui.pushButton.show()
+            #self.ui.pushButton_2.show()
+            #if i == 5:
+            #    self.ui.pushButton_3.show()
+            #    self.ui.pushButton_4.show()
+            #    self.ui.pushButton_5.show()
+            #elif i == 4:
+            #    self.ui.pushButton_3.show()
+            #    self.ui.pushButton_4.show()
+            #elif i == 3:
+            #    self.ui.pushButton_3.show()
+        self.ui.pushButton.setStyleSheet("QPushButton{border:0px;background-image:url('res/sshot1.png')}")
         if(self.sshotcount > 0):
-            img = QPixmap(self.app.thumbnailfile)
-            self.ui.thumbnail.resize(img.width(), img.height())
-            self.ui.thumbnail.setStyleSheet("QPushButton{background-image:url('" + self.app.thumbnailfile + "');border:0px;}")
-            # self.ui.thumbnail.move(400 - img.width() / 2, 521 - img.height() / 2)
-            self.ui.thumbnail.move(430 - img.width() / 2, 380 - img.height() / 2)
+            image = QtGui.QImage()
+            image.load(self.app.thumbnailfile)
+            #print "bbbbbbbbbbbbbbbbbbb",image.width(),image.height()
+            #self.ui.thumbnail.setScaledContents(True)
+            self.ui.thumbnail.setPixmap(QtGui.QPixmap.fromImage(image))
+            self.ui.thumbnail.resize(200,150)
+            self.ui.thumbnail.move(120, 315)
+
             if self.ui.orig_summary_widget.isVisible() is True:
                 self.ui.thumbnail.hide()
             else:
                 self.ui.thumbnail.show()
-        if(self.sshotcount > 1):
-            img = QPixmap(self.app.screenshotfile)
-            self.bigsshot.resize(img.width(), img.height())
-            self.bigsshot.bg.resize(img.width(), img.height())
-            self.bigsshot.bg.setStyleSheet("QLabel{background-image:url('" + self.app.screenshotfile + "');}")
 
+        if i >= 2:
+            ###3
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail1','thumbnail2')
+            image = QtGui.QImage()
+            image.load(self.app.thumbnailfile)
+            self.ui.thumbnail_2.setPixmap(QtGui.QPixmap.fromImage(image))
+            self.ui.thumbnail_2.resize(200,150)
+            self.ui.thumbnail_2.move(336, 315)
+
+            if self.ui.orig_summary_widget.isVisible() is True:
+                self.ui.thumbnail_2.hide()
+            else:
+                self.ui.thumbnail_2.show()
+
+        if i >= 3 :
+            self.app.thumbnailfile = self.app.thumbnailfile.replace('thumbnail2','thumbnail3')
+            image = QtGui.QImage()
+            image.load(self.app.thumbnailfile)
+            self.ui.thumbnail_3.setPixmap(QtGui.QPixmap.fromImage(image))
+            self.ui.thumbnail_3.resize(200,150)
+            self.ui.thumbnail_3.move(552, 315)
+            if self.ui.orig_summary_widget.isVisible() is True:
+                self.ui.thumbnail_3.hide()
+            else:
+                self.ui.thumbnail_3.show()
+
+
+        self.app.thumbnailfile = self.shsave
+        #if(self.sshotcount > 1):
+        #    img = QPixmap(self.app.screenshotfile)
+        #    self.bigsshot.resize(img.width(), img.height())
+        #    self.bigsshot.bg.resize(img.width(), img.height())
+        #    self.bigsshot.bg.setStyleSheet("QLabel{background-image:url('" + self.app.screenshotfile + "');}")
         self.sshotload.stop_loading()
 
+
+
+
     def slot_show_sshot(self):
         if(self.sshotcount > 1):
             self.bigsshot.move_to_center()
@@ -679,7 +954,7 @@ class DetailScrollWidget(QScrollArea):
             self.change_cancel()
 
 
-    def change_start(self):#zx 2015.01.26
+    def change_start(self):
         if(Globals.USER != ''):
             self.ui.name.setReadOnly(False)
             self.ui.name.setStyleSheet("QLineEdit{font-size:28px;font-weight:bold;color:#666666;}")
@@ -700,8 +975,17 @@ class DetailScrollWidget(QScrollArea):
             self.ui.btnSshotBack.hide()
             self.ui.btnSshotNext.hide()
             self.ui.thumbnail.hide()
+            self.ui.thumbnail_2.hide()
+            self.ui.thumbnail_3.hide()
+
+            self.ui.pushButton.hide()
+            self.ui.pushButton_2.hide()
+            self.ui.pushButton_3.hide()
+            self.ui.pushButton_4.hide()
+            self.ui.pushButton_5.hide()
+
         else:
-            self.emit(Signals.show_login)
+            self.show_login.emit()
 
     def change_cancel(self):
         self.ui.name.setText(self.init_name)
@@ -725,16 +1009,32 @@ class DetailScrollWidget(QScrollArea):
         self.ui.btnSshotNext.show()
         if self.sshotcount > 0:
             self.ui.thumbnail.show()
+            self.ui.thumbnail_2.show()
+            self.ui.thumbnail_3.show()
+            #self.ui.pushButton.show()
+            #self.ui.pushButton_2.show()
+            #self.ui.pushButton_3.show()
+            #self.ui.pushButton_4.show()
+            #self.ui.pushButton_5.show()
+
         else:
             self.ui.thumbnail.hide()
+            self.ui.thumbnail_2.hide()
+            self.ui.thumbnail_3.hide()
+            self.ui.pushButton.hide()
+            self.ui.pushButton_2.hide()
+            self.ui.pushButton_3.hide()
+            self.ui.pushButton_4.hide()
+            self.ui.pushButton_5.hide()
+
         self.scrollToTop()
 
-    def slot_change_submit(self):#zx 2015.01.26
+    def slot_change_submit(self):
         if self.app.orig_description == '':
             orig_description = self.app.description
         else:
             orig_description = self.app.orig_description
-        self.appname = str(self.ui.name.text().toUtf8()).strip()
+        self.appname = str(self.ui.name.text()).strip()
         self.summary = str(self.ui.summary.toPlainText()).strip()
         self.description = str(self.ui.description.toPlainText()).strip()
         if(self.appname == '' or self.summary == '' or self.description == ''):
@@ -767,10 +1067,11 @@ class DetailScrollWidget(QScrollArea):
             if(self.appname == self.init_name  and self.summary == self.init_summary  and  self.description == self.init_description):
                 self.mainwindow.messageBox.alert_msg("您未翻译或修改任何部分")
             else:
-                self.emit(Signals.submit_translate_appinfo, self.app.name, self.type_appname, self.type_summary, self.type_description, self.app.displayname, self.app.orig_summary, orig_description, appname, summary, description)
+                self.submit_translate_appinfo.emit(self.app.name, self.type_appname, self.type_summary, self.type_description, self.app.displayname, self.app.orig_summary, orig_description, appname, summary, description)
 
 
     def slot_submit_translate_appinfo_over(self, res):
+        res = res[0]['res']
         #print "************",res
         if(res == 0):
             if self.type_appname == 'True':
@@ -803,7 +1104,7 @@ class DetailScrollWidget(QScrollArea):
             self.mainwindow.messageBox.alert_msg("翻译已提交")
         elif(res == 1):
             self.mainwindow.messageBox.alert_msg("提交过于频繁，请稍后再试")
-        elif 3 == res:
+        elif(res == 3):
             self.messageBox.alert_msg("非数据库中软件\n暂不能对该软件进行翻译")
         elif(res == "False"):
             self.messageBox.alert_msg("连接服务器出错\n"
@@ -821,14 +1122,15 @@ class DetailScrollWidget(QScrollArea):
             if(content.strip() != ''):
                 self.submitreviewload.start_loading()
                 self.ui.bntSubmit.setEnabled(False)
-                self.emit(Signals.submit_review, self.app.name, content)
+                self.submit_review.emit(self.app.name, content)
             else:
                 self.mainwindow.messageBox.alert_msg("不能发表空评论")
         else:
-            self.emit(Signals.show_login)
+            self.show_login.emit()
 
 
     def slot_submit_review_over(self, res):
+        res = res[0]['res']
         self.submitreviewload.stop_loading()
         self.ui.bntSubmit.setEnabled(True)
 
@@ -856,15 +1158,16 @@ class DetailScrollWidget(QScrollArea):
     def slot_submit_rating(self, rating):
         if self.app.from_ukscdb is not True:
             self.messageBox.alert_msg("非数据库中软件\n暂不能对该软件评分")
-            print "ignore submit rating"
+            print("ignore submit rating")
             return
         if(Globals.USER != ''):
             self.submitratingload.start_loading()
-            self.emit(Signals.submit_rating, self.app.name, rating)
+            self.submit_rating.emit(self.app.name, rating)
         else:
-            self.emit(Signals.show_login)
+            self.show_login.emit()
 
     def slot_submit_rating_over(self, res):
+        res = res = res[0]['res']
         if(res != False):
             ratingavg = res['rating_avg']
             ratingtotal = res['rating_total']
@@ -880,7 +1183,7 @@ class DetailScrollWidget(QScrollArea):
         self.app.ratings_average = ratingavg
         self.app.ratings_total = ratingtotal
 
-        ratingavg = str('%.1f' % ratingavg)
+        ratingavg = float('%.1f' % ratingavg)
         self.smallstar.changeGrade(ratingavg)
         self.star.changeGrade(ratingavg)
         self.ui.scorelabel.setText(str(ratingavg))
